package com.th.demo.controller.maint;

import com.alibaba.fastjson.JSON;
import com.th.demo.model.system.ResponseCodeMsg;
import com.th.demo.model.system.ResultJSON;
import com.th.demo.model.system.Type;
import com.th.demo.service.maint.WareService;
import com.th.demo.tools.JSONTools;
import org.activiti.rest.editor.model.ModelEditorJsonRestResource;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;


@RestController
@RequestMapping(value = "/MaintWare")
public class WareController {
    @Autowired
    public WareService wareService;
    String result = Type.FAIL;
    protected static final Logger logger = LoggerFactory.getLogger(ModelEditorJsonRestResource.class);

    @RequestMapping(value = "/query.do")//查询方法 前两个参数是分页参数
    public String query(int page,
                        int rows,
                        String query,
                        HttpServletRequest request) {

        try {
            String userId = (String) request.getAttribute("userId");
            String belongId = (String) request.getAttribute("belongId");
            result = wareService.query(page, rows, query,userId,belongId);
        } catch (Exception ex) {
            ex.printStackTrace();
            result = JSONTools.toString(ResponseCodeMsg.CODE_EX, ex.getMessage());
        } finally {
            return result;
        }
    }

    @RequestMapping(value = "/queryAll.do")//查询方法 前两个参数是分页参数
    public String queryAll(HttpServletRequest request) {

        try {
            String userId = (String) request.getAttribute("userId");
            String belongId = (String) request.getAttribute("belongId");
            result = wareService.queryAll(userId,belongId);
        } catch (Exception ex) {
            ex.printStackTrace();
            result = JSONTools.toString(ResponseCodeMsg.CODE_EX, ex.getMessage());
        } finally {
            return result;
        }
    }


    @RequestMapping(value = "/queryByUserId.do")
    public String queryByUserId(HttpServletRequest request) {
        try {
            String userId = (String) request.getAttribute("userId");
            String belongId = (String) request.getAttribute("belongId");
            result = wareService.queryByUserId(userId,belongId);
        } catch (Exception ex) {
            ex.printStackTrace();
            result = JSONTools.toString(ResponseCodeMsg.CODE_EX, ex.getMessage());
        } finally {
            return result;
        }
    }
    @RequestMapping(value = "/save.do", method = RequestMethod.POST)//Post方法
    public String save(String json,
                       HttpServletRequest request) {
        try {
            String userId = (String) request.getAttribute("userId");
            String belongId = (String) request.getAttribute("belongId");
            result = wareService.save(json, userId,belongId);
        } catch (Exception ex) {
            ex.printStackTrace();
            result = JSON.toJSONString(new ResultJSON(ResponseCodeMsg.CODE_EX, ex.getMessage(), null));
        } finally {
            return result;
        }
    }

    @RequestMapping(value = "/remove.do", method = RequestMethod.POST)
    public String remove(String id,
                         HttpServletRequest request)  {
        try {
            String userId = (String) request.getAttribute("userId");
            String belongId = (String) request.getAttribute("belongId");
            result = wareService.remove(id, userId);
        } catch (NullPointerException ex) {
            ex.printStackTrace();
            result = JSONTools.toString(ResponseCodeMsg.CODE_NULL, ResponseCodeMsg.MSG_NULL);
        } finally {
            return result;
        }
    }
//
    @RequestMapping(value = "/queryWare.do")
    public String queryWare(HttpServletRequest request) {
        String result = ""; // 初始化结果变量
        try {
            String userId = (String) request.getAttribute("userId");
            String belongId = (String) request.getAttribute("belongId");

            // 参数校验
            if (userId == null || belongId == null) {
                result = JSONTools.toString(ResponseCodeMsg.CODE_EX, "用户ID或归属ID缺失");
                return result;
            }
            // 调用服务并序列化结果

            result = wareService.queryWare(userId,belongId);

        } catch(Exception ex) { // 捕获业务异常
            logger.error("业务逻辑异常", ex);
            result = JSONTools.toString(ResponseCodeMsg.CODE_EX, ex.getMessage());
        } finally {
            logger.info("业务逻辑正常");
            return result;
        }
    }
}
